Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'routing/turn_candidate.hpp')
-rw-r--r--routing/turn_candidate.hpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/routing/turn_candidate.hpp b/routing/turn_candidate.hpp
index e06c863c70..dd83385534 100644
--- a/routing/turn_candidate.hpp
+++ b/routing/turn_candidate.hpp
@@ -21,33 +21,33 @@ namespace turns
*/
struct TurnCandidate
{
- /*!
- * angle is an angle of the turn in degrees. It means angle is 180 minus
- * an angle between the current edge and the edge of the candidate. A counterclockwise rotation.
- * The current edge is an edge which belongs the route and located before the junction.
- * angle belongs to the range [-180; 180];
- */
- double angle;
- /*!
- * |m_segment| is a first segment of a possible way from the junction.
- */
+
+/// angle is an angle of the turn in degrees. It means angle is 180 minus
+/// an angle between the current edge and the edge of the candidate. A counterclockwise rotation.
+/// The current edge is an edge which belongs the route and located before the junction.
+/// angle belongs to the range [-180; 180];
+ double m_angle;
+
+/// |m_segment| is a first segment of a possible way from the junction.
Segment m_segment;
- /*!
- * \brief highwayClass field for the road class caching. Because feature reading is a long
- * function.
- */
- ftypes::HighwayClass highwayClass;
-
- TurnCandidate(double a, Segment const & segment, ftypes::HighwayClass c)
- : angle(a), m_segment(segment), highwayClass(c)
+
+/// \brief highwayClass field for the road class caching. Because feature reading is a long
+/// function.
+ ftypes::HighwayClass m_highwayClass;
+
+/// If |isLink| is true than the turn candidate is a link.
+ bool m_isLink;
+
+ TurnCandidate(double a, Segment const & segment, ftypes::HighwayClass c, bool isLink)
+ : m_angle(a), m_segment(segment), m_highwayClass(c), m_isLink(isLink)
{
}
bool IsAlmostEqual(TurnCandidate const & rhs) const
{
double constexpr kEpsilon = 0.01;
- return my::AlmostEqualAbs(angle, rhs.angle, kEpsilon) && m_segment == rhs.m_segment &&
- highwayClass == rhs.highwayClass;
+ return my::AlmostEqualAbs(m_angle, rhs.m_angle, kEpsilon) && m_segment == rhs.m_segment &&
+ m_highwayClass == rhs.m_highwayClass && m_isLink == rhs.m_isLink;
}
};